@@ -4,7 +4,8 @@ use strict;
 use warnings;
 use File::Spec;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
+our $IGNORE_SYMLINK;
 
 sub new {
   my ($class, $file) = @_;
@@ -106,6 +107,7 @@ sub extract {
       return;
     }
     for my $file (@files) {
+      next if $IGNORE_SYMLINK && $file->is_symlink;
       my $path = File::Spec->catfile($dir, $file->prefix, $file->name);
       $tar->extract_file($file, File::Spec->canonpath($path)) or do {
         if (my $error = $tar->error) {
@@ -136,6 +138,7 @@ sub extract {
   $dir = '.' unless defined $dir;
   my $error = 0;
   for my $member ($zip->members) {
+    next if $IGNORE_SYMLINK && $member->isSymbolicLink;
     my $path = File::Spec->catfile($dir, $member->fileName);
     my $ret = $member->extractToFileNamed(File::Spec->canonpath($path));
     $error++ if $ret != AZ_OK;
@@ -160,6 +163,8 @@ Archive::Any::Lite - simple CPAN package extractor
     use warnings;
     use Archive::Any::Lite;
 
+    local $Archive::Any::Lite::IGNORE_SYMLINK = 1; # for safety
+
     my $tarball = 'foo.tar.gz';
     my $archive = Archive::Any::Lite->new($tarball);
     $archive->extract('into/some/directory/');
@@ -205,6 +210,12 @@ Checks to see if this archive is going to unpack outside the current directory.
 
 Deprecated. For backward compatibility only.
 
+=head1 GLOBAL VARIABLE
+
+=head2 $IGNORE_SYMLINK
+
+If set to true, symlinks will be ignored.
+
 =head1 SEE ALSO
 
 L<Archive::Any>, L<Archive::Tar::Streamed>
